@@ -145,8 +145,15 @@ class QoS(virtual.QoS):
     def append(self, message, delivery_tag):
         delivery = message.delivery_info
         EX, RK = delivery['exchange'], delivery['routing_key']
+        # TODO: Remove this once we soley on Redis-py 3.0.0+
+        if redis.VERSION[0] >= 3:
+            # Redis-py changed the format of zadd args in v3.0.0
+            zadd_args = [{delivery_tag: time()}]
+        else:
+            zadd_args = [time(), delivery_tag]
+
         with self.pipe_or_acquire() as pipe:
-            pipe.zadd(self.unacked_index_key, time(), delivery_tag) \
+            pipe.zadd(self.unacked_index_key, *zadd_args) \
                 .hset(self.unacked_key, delivery_tag,
                       dumps([message._raw, EX, RK])) \
                 .execute()
@@ -761,7 +768,7 @@ class Channel(virtual.Channel):
 
     def _put(self, queue, message, **kwargs):
         """Deliver message."""
-        pri = self._get_message_priority(message, reverse=True)
+        pri = self._get_message_priority(message, reverse=False)
 
         with self.conn_or_acquire() as client:
             client.lpush(self._q_for_pri(queue, pri), dumps(message))
@@ -871,7 +878,7 @@ class Channel(virtual.Channel):
                                socket_keepalive_options=None, **params):
         return params
 
-    def _connparams(self, async=False):
+    def _connparams(self, asynchronous=False):
         conninfo = self.connection.client
         connparams = {
             'host': conninfo.hostname or '127.0.0.1',
@@ -894,7 +901,7 @@ class Channel(virtual.Channel):
                 pass
         host = connparams['host']
         if '://' in host:
-            scheme, _, _, _, _, path, query = _parse_url(host)
+            scheme, _, _, _, password, path, query = _parse_url(host)
             if scheme == 'socket':
                 connparams = self._filter_tcp_connparams(**connparams)
                 connparams.update({
@@ -904,6 +911,7 @@ class Channel(virtual.Channel):
                 connparams.pop('socket_connect_timeout', None)
                 connparams.pop('socket_keepalive', None)
                 connparams.pop('socket_keepalive_options', None)
+            connparams['password'] = password
 
             connparams.pop('host', None)
             connparams.pop('port', None)
@@ -916,7 +924,7 @@ class Channel(virtual.Channel):
             self.connection_class
         )
 
-        if async:
+        if asynchronous:
             class Connection(connection_cls):
                 def disconnect(self):
                     super(Connection, self).disconnect()
@@ -927,20 +935,20 @@ class Channel(virtual.Channel):
 
         return connparams
 
-    def _create_client(self, async=False):
-        if async:
+    def _create_client(self, asynchronous=False):
+        if asynchronous:
             return self.Client(connection_pool=self.async_pool)
         return self.Client(connection_pool=self.pool)
 
-    def _get_pool(self, async=False):
-        params = self._connparams(async=async)
+    def _get_pool(self, asynchronous=False):
+        params = self._connparams(asynchronous=asynchronous)
         self.keyprefix_fanout = self.keyprefix_fanout.format(db=params['db'])
         return redis.ConnectionPool(**params)
 
     def _get_client(self):
-        if redis.VERSION < (2, 10, 0):
+        if redis.VERSION < (2, 10, 5):
             raise VersionMismatch(
-                'Redis transport requires redis-py versions 2.10.0 or later. '
+                'Redis transport requires redis-py versions 2.10.5 or later. '
                 'You have {0.__version__}'.format(redis))
         return redis.StrictRedis
 
@@ -960,18 +968,18 @@ class Channel(virtual.Channel):
     @property
     def async_pool(self):
         if self._async_pool is None:
-            self._async_pool = self._get_pool(async=True)
+            self._async_pool = self._get_pool(asynchronous=True)
         return self._async_pool
 
     @cached_property
     def client(self):
         """Client used to publish messages, BRPOP etc."""
-        return self._create_client(async=True)
+        return self._create_client(asynchronous=True)
 
     @cached_property
     def subclient(self):
         """Pub/Sub connection used to consume fanout queues."""
-        client = self._create_client(async=True)
+        client = self._create_client(asynchronous=True)
         return client.pubsub()
 
     def _update_queue_cycle(self):
@@ -999,7 +1007,7 @@ class Transport(virtual.Transport):
     driver_name = 'redis'
 
     implements = virtual.Transport.implements.extend(
-        async=True,
+        asynchronous=True,
         exchange_type=frozenset(['direct', 'topic', 'fanout'])
     )
 
@@ -1059,7 +1067,7 @@ class SentinelChannel(Channel):
     `Connection` object).
 
     You must provide at least one option in Transport options:
-     * `service_name` - name of the redis group to poll
+     * `master_name` - name of the redis group to poll
     """
 
     from_transport_options = Channel.from_transport_options + (
@@ -1069,8 +1077,8 @@ class SentinelChannel(Channel):
 
     connection_class = sentinel.SentinelManagedConnection if sentinel else None
 
-    def _sentinel_managed_pool(self, async=False):
-        connparams = self._connparams(async)
+    def _sentinel_managed_pool(self, asynchronous=False):
+        connparams = self._connparams(asynchronous)
 
         additional_params = connparams.copy()
 
@@ -1090,8 +1098,8 @@ class SentinelChannel(Channel):
             self.Client,
         ).connection_pool
 
-    def _get_pool(self, async=False):
-        return self._sentinel_managed_pool(async)
+    def _get_pool(self, asynchronous=False):
+        return self._sentinel_managed_pool(asynchronous)
 
 
 class SentinelTransport(Transport):
